==> ciscoisesdk-0.5.1-py3-none-any.whl: ciscoisesdk/models/validators/v3_0_0/jsd_b994e6c8b8d53f29230686824c9fafa.py <==
# -*- coding: utf-8 -*-
"""Identity Services Engine scheduleConfigBackup data model.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from ciscoisesdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorB994E6C8B8D53F29230686824C9Fafa(object):
    """scheduleConfigBackup request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB994E6C8B8D53F29230686824C9Fafa, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "backupDescription": {
                "type": "string"
                },
                "backupEncryptionKey": {
                "type": "string"
                },
                "backupName": {
                "type": "string"
                },
                "endDate": {
                "type": "string"
                },
                "frequency": {
                "enum": [
                "ONE_TIME",
                "DAILY",
                "WEEKLY",
                "MONTHLY"
                ],
                "type": "string"
                },
                "repositoryName": {
                "type": "string"
                },
                "startDate": {
                "type": "string"
                },
                "time": {
                "type": "string"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> ciscoisesdk-1.0.1-py3-none-any.whl: ciscoisesdk/models/validators/v3_0_0/jsd_b994e6c8b8d53f29230686824c9fafa.py <==
# -*- coding: utf-8 -*-
"""Identity Services Engine createScheduledConfigBackup data model.

Copyright (c) 2021 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from ciscoisesdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorB994E6C8B8D53F29230686824C9Fafa(object):
    """createScheduledConfigBackup request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB994E6C8B8D53F29230686824C9Fafa, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "backupDescription": {
                "type": "string"
                },
                "backupEncryptionKey": {
                "type": "string"
                },
                "backupName": {
                "type": "string"
                },
                "endDate": {
                "type": "string"
                },
                "frequency": {
                "enum": [
                "ONCE",
                "DAILY",
                "WEEKLY",
                "MONTHLY"
                ],
                "type": "string"
                },
                "monthDay": {
                "type": "string"
                },
                "repositoryName": {
                "type": "string"
                },
                "startDate": {
                "type": "string"
                },
                "status": {
                "enum": [
                "ENABLE",
                "DISABLE"
                ],
                "type": "string"
                },
                "time": {
                "type": "string"
                },
                "weekDay": {
                "enum": [
                "MON",
                "TUE",
                "WED",
                "THU",
                "FRI",
                "SAT",
                "SUN"
                ],
                "type": "string"
                }
                },
                "required": [
                "backupEncryptionKey",
                "backupName",
                "frequency",
                "repositoryName",
                "startDate",
                "time"
                ],
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
